Crate colorize_rs

Crate colorize_rs 

Enums

BgColor
Color
Ansi color to set the global foreground / background color
Style

Traits

AnsiColor
Methods extension to colorize the text contained in a string using a simple mathod call

Functions

color_enabled
Set color to be enabled / disabled
global_bg
Set a custom global background color
global_fg
Set a custom global foreground color
reset
Reset the background and foreground color to the defaults colors