Enums
Traits
- Ansi
Color - Methods extension to colorize the text contained in a string using a simple mathod call
Functions
- color_
enabled - Set color to be enabled / disabled
- global_
bg - Set a custom global background color
- global_
fg - Set a custom global foreground color
- reset
- Reset the background and foreground color to the defaults colors